#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_INF_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_INF_HPP_INCLUDED

#include <boost/simd/constant/include/constants/inf.hpp>

#endif
